{
    package GCLang::IT::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2010 Christian Jodar
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#######################################################
#
#  v1.0.2 - Italian localization by Andreas Troschka
#
#  for GCstar v1.1.1
#
#######################################################

    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Biblioteca',
        Items => {0 => 'Libri',
                  1 => 'Libri',
                  X => 'Libris'},
        NewItem => 'Libro nuovo',
    
        Isbn => 'ISBN',
        Title => 'Titolo',
        Cover => 'Copertina',
        Authors => 'Autore(i)',
        Publisher => 'Editore',
        Publication => 'Data di pubblicazione',
        Language => 'Lingua',
        Genre => 'Genere',
        Serie => 'Serie',
        Rank => 'Rank',
        Bookdescription => 'Descrizione',
        Pages => 'Pagine',
        Read => 'Letto',
        Acquisition => 'Acquisito il',
        Edition => 'Edizione',
        Format => 'Formato',
        Comments => 'Commenti',
        Url => 'Pagina web',
        Translator => 'Traduttore',
        Artist => 'Scrittore',
        DigitalFile => 'Digital version',

        General => 'Generale',
        Details => 'Dettagli',

        ReadNo => 'Non letto',
        ReadYes => 'Letto',
     );
}

1;
