C:\Perl\bin\pp -o gcstar.exe -g -B -M filetest -M Glib::Object::Subclass  -M locale -M Digest::MD5 -M MIME::Base64 -M LWP -M LWP::Simple -M LWP::UserAgent -M Net::SMTP -M URI::Escape   -M HTTP::Cookies::Netscape -M HTML::Entities -M Gtk2::SimpleList -M Text::Wrap -M XML::Simple -M MP3::Info -M MP3::Tag -M Net::FreeDB -M DateTime::Format::Strptime -M Archive::Tar -M Archive::Zip -M Compress::Zlib -M Time::Piece -M Ogg::Vorbis::Header::PurePerl -M Getopt::Long -M FindBin -M Gtk2::Gdk::Keysyms -M Unicode::Normalize -M GD -M GD::Text -M GD::Graph::bars -M GD::Graph::area -M GD::Graph::pie -M Date::Calc -a "..\lib\gcstar;lib" -a "..\share\gcstar;share" --link=C:\Perl\site\lib\auto\Cairo\Cairo.dll  --link=C:\Perl\site\lib\auto\Glib\Glib.dll --link=C:\Perl\site\lib\auto\Gtk2\Gtk2.dll -vvv --icon=..\share\gcstar\icons\GCstar.ico  --info="ProductName=GCstar;ProductVersion=1.6.1;FileVersion=1.6.1;FileDescription=GCstar, Personal Collections Manager;Comments=http://www.gcstar.org;LegalCopyright=GNU GPL"  gcstar